@@ -15,6 +15,6 @@ check_dep_bin asciidoc asciidoc
 check_dep_bin dblatex dblatex
 check_dep_bin packetdiag3 python3-nwdiag
 check_dep_bin dot graphviz
-check_dep_bin inkscape inkscape
+check_dep_bin rsvg-convert librsvg2-bin
 
 echo "All dependencies installed!"
